IQM Pulse library
=================

A Python-based project for providing interface and implementations for control pulses.

Status
------

The **iqm-pulse** project is under development.

Development
-----------

Please refer to `user <https://iqm.gitlab-pages.iqm.fi/qccsw/continuous-delivery/ccp/Q5/docs/qccsw-docs/exa/user_guide/>`_
and `developer <https://wiki.iqm.fi/x/EvrnC>`_  guidelines.

Documentation
-------------

* The full EXA documentation `Spark <https://iqm.gitlab-pages.iqm.fi/qccsw/continuous-delivery/ccp/spark/>`_ or `Radiance <https://iqm.gitlab-pages.iqm.fi/qccsw/continuous-delivery/ccp/radiance/>`_
* The `API documentation <https://iqm.gitlab-pages.iqm.fi/qccsw/exa/exa-repo/iqm-pulse/>`_
  is updated and deployed on every successful build in master.
* `Additional project documentation <https://wiki.iqm.fi/x/iPnnC>`_
  may be found in the IQM wiki.

License
-------

Copyright (c) 2019-2024 IQM Finland Oy.

All rights reserved. Confidential and proprietary.

Distribution or reproduction of any information contained herein is prohibited
without IQM Finland Oy's prior written permission.
